# Table of Contents

- [sending-alerts-to-slack-and-microsoft-teams](<./sending-alerts-to-slack-and-microsoft-teams.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Sending Alerts to Slack and Microsoft Teams](<./Sending-Alerts-to-Slack-and-Microsoft-Teams.md>)
  - [Sending Alerts to Slack](<./Sending-Alerts-to-Slack-and-Microsoft-Teams/Sending-Alerts-to-Slack.md>)
  - [Sending Alerts to Microsoft Teams](<./Sending-Alerts-to-Slack-and-Microsoft-Teams/Sending-Alerts-to-Microsoft-Teams.md>)
